@@ -82,8 +82,10 @@ type Writer struct {
 	Colors             *Colors
 	ParentColors       []*Colors
 	AnsiColors         ColorString
-	Plain              bool
-	TrueColor          bool
+
+	Plain       bool
+	TrueColor   bool
+	Interactive bool
 
 	builder strings.Builder
 	length  int
@@ -111,6 +113,9 @@ type Writer struct {
 	osc7                  string
 	osc51                 string
 
+	lastRune        rune
+	escapeSequences map[rune]rune
+
 	hyperlinkStart  string
 	hyperlinkCenter string
 	hyperlinkEnd    string
@@ -144,6 +149,10 @@ func (w *Writer) Init(shellName string) {
 		w.iTermPromptMark = "\\[$(iterm2_prompt_mark)\\]"
 		w.iTermCurrentDir = "\\[\x1b]1337;CurrentDir=%s\x07\\]"
 		w.iTermRemoteHost = "\\[\x1b]1337;RemoteHost=%s@%s\x07\\]"
+		w.escapeSequences = map[rune]rune{
+			96: 92, // backtick
+			92: 92, // backslash
+		}
 	case shell.ZSH, shell.TCSH:
 		w.format = "%%{%s%%}"
 		w.linechange = "%%{\x1b[%d%s%%}"
@@ -184,6 +193,13 @@ func (w *Writer) Init(shellName string) {
 		w.iTermCurrentDir = "\x1b]1337;CurrentDir=%s\x07"
 		w.iTermRemoteHost = "\x1b]1337;RemoteHost=%s@%s\x07"
 	}
+
+	if shellName == shell.ZSH {
+		w.escapeSequences = map[rune]rune{
+			96: 92, // backtick
+			37: 37, // %
+		}
+	}
 }
 
 func (w *Writer) SetColors(background, foreground string) {
@@ -207,11 +223,14 @@ func (w *Writer) ChangeLine(numberOfLines int) string {
 	if w.Plain {
 		return ""
 	}
+
 	position := "B"
+
 	if numberOfLines < 0 {
 		position = "F"
 		numberOfLines = -numberOfLines
 	}
+
 	return fmt.Sprintf(w.linechange, numberOfLines, position)
 }
 
@@ -219,9 +238,11 @@ func (w *Writer) ConsolePwd(pwdType, userName, hostName, pwd string) string {
 	if w.Plain {
 		return ""
 	}
+
 	if strings.HasSuffix(pwd, ":") {
 		pwd += "\\"
 	}
+
 	switch pwdType {
 	case OSC7:
 		return fmt.Sprintf(w.osc7, hostName, pwd)
@@ -238,6 +259,7 @@ func (w *Writer) ClearAfter() string {
 	if w.Plain {
 		return ""
 	}
+
 	return w.clearLine + w.clearBelow
 }
 
@@ -246,6 +268,7 @@ func (w *Writer) FormatTitle(title string) string {
 	if w.Plain {
 		return title
 	}
+
 	// we have to do this to prevent bash/zsh from misidentifying escape sequences
 	switch w.shell {
 	case shell.BASH:
@@ -256,6 +279,7 @@ func (w *Writer) FormatTitle(title string) string {
 		// these shells don't support setting the title
 		return ""
 	}
+
 	return fmt.Sprintf(w.title, title)
 }
 
@@ -416,10 +440,21 @@ func (w *Writer) write(s rune) {
 		return
 	}
 
-	if !w.hyperlink {
-		w.length += runewidth.RuneWidth(s)
+	if w.hyperlink {
+		w.builder.WriteRune(s)
+		return
 	}
 
+	if !w.Interactive {
+		for special, escape := range w.escapeSequences {
+			if s == special && w.lastRune != escape {
+				w.builder.WriteRune(escape)
+			}
+		}
+	}
+
+	w.length += runewidth.RuneWidth(s)
+	w.lastRune = s
 	w.builder.WriteRune(s)
 }
 
